@@ -19,7 +19,7 @@ Andrew DeFaria <Andrew@DeFaria.com>
 
 =item Revision
 
-$Revision: 1.0 $
+$Revision: 2.23 $
 
 =item Created
 
@@ -27,7 +27,7 @@ Fri Sep 22 09:21:18 CDT 2006
 
 =item Modified
 
-Fri Feb 06 08:30:00 PST 2026
+2013/03/28 22:48:07
 
 =back
 
@@ -158,34 +158,18 @@ use File::Basename;
 use Carp;
 use Time::Local;
 
-use File::Spec;
-
 sub _GetConfig($);
 
 # Seed options from config file
-my $config = $ENV{CQ_CONF};
+my $config = $ENV{CQ_CONF} || '/etc/clearquest/cq.conf';
 
-unless ($config) {
-  my $dir            = dirname (__FILE__);
-  my $local_conf     = File::Spec->catfile ($dir, '..', 'etc', 'cq.conf');
-  my $installed_conf = File::Spec->catfile ($dir, 'Clearquest', 'cq.conf');
-
-  if (-r $local_conf) {
-    $config = $local_conf;
-  } elsif (-r $installed_conf) {
-    $config = $installed_conf;
-  } elsif (-r '/etc/clearquest/cq.conf') {
-    $config = '/etc/clearquest/cq.conf';
-  }    # if
-}    # unless
-
-croak "Unable to find config file" unless $config and -r $config;
+croak "Unable to find config file $config" unless -r $config;
 
 our %OPTS = _GetConfig ($config);
 
 my $DEFAULT_DBSET = $OPTS{CQ_DBSET};
 
-our $VERSION = '1.02';
+our $VERSION = '2.23';
 
 # Override options if in the environment
 $OPTS{CQ_DATABASE} = $ENV{CQ_DATABASE} if $ENV{CQ_DATABASE};
